@@ -19,6 +19,8 @@ p = Procedures(
             animal_weight_prior=22.6,
             animal_weight_post=22.3,
             anaesthesia=Anaesthetic(type="Isoflurane", duration=1, level=1.5),
+            bregma_to_lambda_distance=4.1,
+            craniotomy_coordinates_reference="Lambda",
             craniotomy_size=5,
             workstation_id="SWS 3",
         ),
@@ -39,6 +41,8 @@ p = Procedures(
             injection_coordinate_ml=-0.87,
             injection_coordinate_ap=-3.8,
             injection_coordinate_depth=-3.3,
+            injection_coordinate_reference="Lambda",
+            bregma_to_lambda_distance=4.1,
             injection_angle=10,
             injection_volume=200,
             targeted_structure="VISp",
